@@ -264,6 +264,19 @@ if (! window._OQAjaxQueryLoaded)
     return true;
   });
 
+  $(document).delegate('.OQRemoveAutoActionBut', 'click', function(e) {
+    var $f = $('.OQform');
+    var $elem = $(this).closest(".AutoActionSummaryElem");
+    var dat = {};
+    dat.module = 'InteractiveQuery2Tools';
+    dat.tool = 'autoaction';
+    dat.OQRemoveAutoAction = $(this).attr('data-id');
+    $.ajax({ url: $f[0].action, type: 'POST', data: dat, dataType: 'html', complete: OQnotify,
+      success: function(){ $elem.remove(); }
+    });
+    return true;
+  });
+
   $(document).delegate('.OQEmailMergeDeleteAutoActionBut', 'click', function(e) {
     var $f = $('.OQform');
     var dat = {};
